"""Annotate to add specify attribute for tiramisu-cmdline

Silique (https://www.silique.fr)
Copyright (C) 2024

distribued with GPL-2 or later license

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""
from rougail.annotator.variable import Walk

class Annotator(Walk):
    """Annotate value"""
    level = 5

    def __init__(self, objectspace, *args) -> None:
        if not objectspace.paths:
            return
        self.objectspace = objectspace
        self.manage_alternative_name()
        self.not_for_commandline()

    def manage_alternative_name(self) -> None:
        for variable in self.get_variables():
            if variable.type == 'symlink':
                continue
            if not variable.alternative_name:
                continue
            alternative_name = variable.alternative_name
            variable_path = variable.path
            if '.' not in variable_path:
                path = alternative_name
            else:
                path = variable_path.rsplit('.', 1)[0] + '.' + alternative_name
            self.objectspace.add_variable(alternative_name, {'type': 'symlink', 'path': path, 'opt': variable}, variable.xmlfiles, False, False, variable.version)

    def not_for_commandline(self) -> None:
        for variable in self.get_variables():
            if not hasattr(variable, 'commandline') or variable.commandline:
                continue
            self.objectspace.properties.add(variable.path, 'not_for_commandline', True)
